==> apache-ambari-2.6.2-src.tar.gz: apache-ambari-2.6.2-src/ambari-web/app/models/view_instance.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var App = require('app');

App.ViewInstance = Em.Object.extend({

  /**
   * @type {string}
   */
  iconPath: '',

  /**
   * @type {string}
   */
  label: '',

  /**
   * @type {boolean}
   */
  visible: false,

  /**
   * @type {string}
   */
  version: '',

  /**
   * @type {string}
   */
  description: '',

  /**
   * @type {string}
   */
  viewName: '',

  /**
   * @type {string}
   */
  shortUrl: '',

  /**
   * @type {string}
   */
  instanceName: '',

  /**
   * @type {string}
   */
  href: '',

  /**
   * @type {string}
   */
  internalAmbariUrl: function () {
    var shortUrl = this.get('shortUrl');
    var viewName = this.get('viewName');
    var version = this.get('version');
    var instanceName = this.get('instanceName');
    if(shortUrl) {
      return 'main/view/' + viewName + '/' + shortUrl;
    }
    return 'main/views/' + viewName + '/' + version + '/' + instanceName;
  }.property('shortUrl', 'viewName', 'version', 'instanceName')
});

==> apache-ambari-2.7.9-src.tar.gz: apache-ambari-2.7.9-src/ambari-web/app/models/view_instance.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var App = require('app');

App.ViewInstance = Em.Object.extend({

  /**
   * @type {string}
   */
  iconPath: '',

  /**
   * @type {string}
   */
  label: '',

  /**
   * @type {boolean}
   */
  visible: false,

  /**
   * @type {string}
   */
  version: '',

  /**
   * @type {string}
   */
  description: '',

  /**
   * @type {string}
   */
  viewName: '',

  /**
   * @type {string}
   */
  shortUrl: '',

  /**
   * @type {string}
   */
  instanceName: '',

  /**
   * @type {string}
   */
  href: '',

  /**
   * @type {string}
   */
  internalAmbariUrl: function () {
    var shortUrl = this.get('shortUrl');
    var viewName = this.get('viewName');
    var version = this.get('version');
    var instanceName = this.get('instanceName');
    if(shortUrl) {
      return '#/main/view/' + viewName + '/' + shortUrl;
    }
    return '#/main/views/' + viewName + '/' + version + '/' + instanceName;
  }.property('shortUrl', 'viewName', 'version', 'instanceName')
});
